@@ -27,7 +27,7 @@
 ##
 import logging
 import re
-import os
+from MuPythonLibrary.UtilityFunctions import GetHostInfo
 try:
     # try to import windows types from winDLL
     import ctypes
@@ -195,9 +195,11 @@ class ColoredFormatter(logging.Formatter):
         'WARNING': AnsiColor.YELLOW,
         'INFO': AnsiColor.CYAN,
         'DEBUG': AnsiColor.BLUE,
-        'CRITICAL': AnsiColor.GREEN,
+        'CRITICAL': AnsiColor.MAGENTA,
         'ERROR': AnsiColor.RED,
-        "STATUS": AnsiColor.MAGENTA
+        "STATUS": AnsiColor.GREEN,
+        "PROGRESS": AnsiColor.GREEN,
+        "SECTION": AnsiColor.CYAN
     }
 
     def __init__(self, msg="", use_azure=False):
@@ -209,8 +211,10 @@ class ColoredFormatter(logging.Formatter):
         org_message = record.msg
 
         if not self.use_azure and levelname in ColoredFormatter.COLORS:
+            # just color the level name
             if record.levelno < logging.WARNING:
                 levelname_color = get_ansi_string(ColoredFormatter.COLORS[levelname]) + levelname + get_ansi_string()
+            # otherwise color the wholes message
             else:
                 levelname_color = get_ansi_string(ColoredFormatter.COLORS[levelname]) + levelname
                 record.msg += get_ansi_string()
@@ -244,7 +248,7 @@ class ColoredStreamHandler(logging.StreamHandler):
 
     def __init__(self, stream=None, strip=None, convert=None):
         logging.StreamHandler.__init__(self, stream)
-        self.on_windows = os.name == 'nt'
+        self.on_windows = GetHostInfo().os == "Windows"
         # We test if the WinAPI works, because even if we are on Windows
         # we may be using a terminal that doesn't support the WinAPI
         # (e.g. Cygwin Terminal). In this case it's up to the terminal
